@@ -1,6 +1,9 @@
 test_that("minimal", {
-  repo <- makeRepo()
-  testthat::skip_if_not(all(class(repo) == c("Repository", "R6")))
+  skip_if_offline()
+  skip_if_not(repoCloned)
+
+  repo <- Repository$new(path)
+
   files <- repo$getRFiles()
   glueIdx <- sapply(files, function(file) {
     file$getName() == "glue.R"
@@ -19,5 +22,4 @@ test_that("minimal", {
   df <- bind_rows(PaRe:::getFunCall(fun, defFuns))
   expect_true(nrow(df) == 1)
   expect_true(ncol(df) == 2)
-  unlink(repo$getPath(), recursive = TRUE)
 })
